Topia-commits
Threads by month
- ----- 2026 -----
- June
- May
- April
- March
- February
- January
- ----- 2025 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2024 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2023 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2022 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2021 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2020 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2019 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2018 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2017 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2016 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2015 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2014 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2013 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2012 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2011 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2010 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2009 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2008 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2007 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2006 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2005 -----
- December
- November
- October
- September
- August
- July
- June
- May
- April
- March
- February
- January
- ----- 2004 -----
- December
- November
- October
- September
- August
- July
- June
- May
December 2012
- 1 participants
- 9 discussions
30 Dec '12
Author: tchemit
Date: 2012-12-30 22:45:12 +0100 (Sun, 30 Dec 2012)
New Revision: 2705
Url: http://nuiton.org/projects/topia/repository/revisions/2705
Log:
adding license header and missing svn properties
Modified:
trunk/doc/migration-to-topia-3.rst
trunk/topia-persistence-hibernate/src/license/THIRD-PARTY.properties
trunk/topia-persistence-tck/src/license/THIRD-PARTY.properties
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/BidiAssociationClassTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/ManyToManyAssociationClassTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/OneToManyAssociationClassTest.java
trunk/topia-service-migration/src/main/resources/org/nuiton/topia/migration/mappings/TMSVersion-orm.xml
trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationCallback.java
trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java
trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationV1_2.java
trunk/topia-service-migration/src/test/resources/META-INF/services/org.nuiton.topia.migration.TopiaMigrationCallbackByClassNG$MigrationCallBackForVersion
trunk/topia-service-migration/src/test/resources/migration-source-database.h2.db
Property changes on: trunk/doc/migration-to-topia-3.rst
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Property changes on: trunk/topia-persistence-hibernate/src/license/THIRD-PARTY.properties
___________________________________________________________________
Modified: svn:keywords
- Author Date Id Revision
+ Author Date Id Revision HeadURL
Property changes on: trunk/topia-persistence-tck/src/license/THIRD-PARTY.properties
___________________________________________________________________
Modified: svn:keywords
- Author Date Id Revision
+ Author Date Id Revision HeadURL
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/BidiAssociationClassTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/BidiAssociationClassTest.java 2012-12-30 21:43:38 UTC (rev 2704)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/BidiAssociationClassTest.java 2012-12-30 21:45:12 UTC (rev 2705)
@@ -1,5 +1,29 @@
package org.nuiton.topia.tck.mapping.test14;
+/*
+ * #%L
+ * ToPIA :: Persistence :: Test Compatibility Kit
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2012 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
import org.junit.Assert;
import org.junit.Before;
import org.junit.Ignore;
Property changes on: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/BidiAssociationClassTest.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/ManyToManyAssociationClassTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/ManyToManyAssociationClassTest.java 2012-12-30 21:43:38 UTC (rev 2704)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/ManyToManyAssociationClassTest.java 2012-12-30 21:45:12 UTC (rev 2705)
@@ -1,5 +1,29 @@
package org.nuiton.topia.tck.mapping.test14;
+/*
+ * #%L
+ * ToPIA :: Persistence :: Test Compatibility Kit
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2012 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
import org.junit.Assert;
import org.junit.Before;
import org.junit.Ignore;
Property changes on: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/ManyToManyAssociationClassTest.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/OneToManyAssociationClassTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/OneToManyAssociationClassTest.java 2012-12-30 21:43:38 UTC (rev 2704)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/OneToManyAssociationClassTest.java 2012-12-30 21:45:12 UTC (rev 2705)
@@ -1,5 +1,29 @@
package org.nuiton.topia.tck.mapping.test14;
+/*
+ * #%L
+ * ToPIA :: Persistence :: Test Compatibility Kit
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2012 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
Property changes on: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test14/OneToManyAssociationClassTest.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/topia-service-migration/src/main/resources/org/nuiton/topia/migration/mappings/TMSVersion-orm.xml
===================================================================
--- trunk/topia-service-migration/src/main/resources/org/nuiton/topia/migration/mappings/TMSVersion-orm.xml 2012-12-30 21:43:38 UTC (rev 2704)
+++ trunk/topia-service-migration/src/main/resources/org/nuiton/topia/migration/mappings/TMSVersion-orm.xml 2012-12-30 21:45:12 UTC (rev 2705)
@@ -1,4 +1,28 @@
<?xml version="1.0" encoding="UTF-8"?>
+<!--
+ #%L
+ ToPIA :: Service Migration
+ $Id$
+ $HeadURL$
+ %%
+ Copyright (C) 2004 - 2012 CodeLutin
+ %%
+ This program is free software: you can redistribute it and/or modify
+ it under the terms of the GNU Lesser General Public License as
+ published by the Free Software Foundation, either version 3 of the
+ License, or (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ GNU General Lesser Public License for more details.
+
+ You should have received a copy of the GNU General Lesser Public
+ License along with this program. If not, see
+ <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ #L%
+ -->
+
<entity-mappings version="2.0" xmlns="http://java.sun.com/xml/ns/persistence/orm" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://java.sun.com/xml/ns/persistence/orm http://java.sun.com/xml/ns/persistence/orm_2_0.xsd">
<entity class="org.nuiton.topia.migration.mappings.TMSVersion">
Property changes on: trunk/topia-service-migration/src/main/resources/org/nuiton/topia/migration/mappings/TMSVersion-orm.xml
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationCallback.java
===================================================================
--- trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationCallback.java 2012-12-30 21:43:38 UTC (rev 2704)
+++ trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationCallback.java 2012-12-30 21:45:12 UTC (rev 2705)
@@ -1,5 +1,29 @@
package org.nuiton.topia.migration;
+/*
+ * #%L
+ * ToPIA :: Service Migration
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2012 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
import org.nuiton.topia.tck.it.TopiaTckItDAOHelper;
import org.nuiton.util.Version;
import org.nuiton.util.VersionUtil;
Property changes on: trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationCallback.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java
===================================================================
--- trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java 2012-12-30 21:43:38 UTC (rev 2704)
+++ trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java 2012-12-30 21:45:12 UTC (rev 2705)
@@ -1,5 +1,29 @@
package org.nuiton.topia.migration;
+/*
+ * #%L
+ * ToPIA :: Service Migration
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2012 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
import com.google.common.io.Files;
import com.google.common.io.InputSupplier;
import org.junit.Assert;
Property changes on: trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Modified: trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationV1_2.java
===================================================================
--- trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationV1_2.java 2012-12-30 21:43:38 UTC (rev 2704)
+++ trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationV1_2.java 2012-12-30 21:45:12 UTC (rev 2705)
@@ -1,5 +1,29 @@
package org.nuiton.topia.migration;
+/*
+ * #%L
+ * ToPIA :: Service Migration
+ * $Id$
+ * $HeadURL$
+ * %%
+ * Copyright (C) 2004 - 2012 CodeLutin
+ * %%
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Lesser Public License for more details.
+ *
+ * You should have received a copy of the GNU General Lesser Public
+ * License along with this program. If not, see
+ * <http://www.gnu.org/licenses/lgpl-3.0.html>.
+ * #L%
+ */
+
import org.nuiton.topia.TopiaException;
import org.nuiton.topia.framework.TopiaContextImplementor;
import org.nuiton.util.Version;
Property changes on: trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationV1_2.java
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Property changes on: trunk/topia-service-migration/src/test/resources/META-INF/services/org.nuiton.topia.migration.TopiaMigrationCallbackByClassNG$MigrationCallBackForVersion
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
Added: svn:eol-style
+ native
Property changes on: trunk/topia-service-migration/src/test/resources/migration-source-database.h2.db
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision HeadURL
1
0
r2704 - in trunk: topia-persistence/src/license topia-persistence-hibernate topia-persistence-hibernate/src topia-persistence-hibernate/src/license topia-persistence-tck topia-persistence-tck/src topia-persistence-tck/src/license topia-service-migration/src/license topia-service-replication/src/license topia-service-security/src/license
by tchemit@users.nuiton.org 30 Dec '12
by tchemit@users.nuiton.org 30 Dec '12
30 Dec '12
Author: tchemit
Date: 2012-12-30 22:43:38 +0100 (Sun, 30 Dec 2012)
New Revision: 2704
Url: http://nuiton.org/projects/topia/repository/revisions/2704
Log:
optimize license and third parties
Added:
trunk/topia-persistence-hibernate/src/license/
trunk/topia-persistence-hibernate/src/license/THIRD-PARTY.properties
trunk/topia-persistence-tck/src/license/
trunk/topia-persistence-tck/src/license/THIRD-PARTY.properties
Modified:
trunk/topia-persistence-hibernate/LICENSE.txt
trunk/topia-persistence-tck/LICENSE.txt
trunk/topia-persistence/src/license/THIRD-PARTY.properties
trunk/topia-service-migration/src/license/THIRD-PARTY.properties
trunk/topia-service-replication/src/license/THIRD-PARTY.properties
trunk/topia-service-security/src/license/THIRD-PARTY.properties
Modified: trunk/topia-persistence/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/topia-persistence/src/license/THIRD-PARTY.properties 2012-12-30 21:41:01 UTC (rev 2703)
+++ trunk/topia-persistence/src/license/THIRD-PARTY.properties 2012-12-30 21:43:38 UTC (rev 2704)
@@ -2,7 +2,6 @@
#-------------------------------------------------------------------------------
# Already used licenses in project :
# - BSD License
-# - BSD style
# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
# - Common Public License Version 1.0
# - Indiana University Extreme! Lab Software License, vesion 1.1.1
@@ -10,20 +9,17 @@
# - Lesser General Public License (LPGL)
# - Lesser General Public License (LPGL) v 2.1
# - MIT License
-# - MPL 1.1
# - Mozilla Public License Version 1.0
+# - New BSD License
# - The Apache Software License, Version 2.0
# - The H2 License, Version 1.0
+# - The SAX License
+# - The W3C License
# - http://jaxen.codehaus.org/license.html
-# - license.txt
#-------------------------------------------------------------------------------
# Please fill the missing licenses for dependencies :
#
#
-#Thu Jan 12 16:55:28 CET 2012
-antlr--antlr--2.7.6=BSD License
+#Sun Dec 30 22:42:08 CET 2012
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
dom4j--dom4j--1.6.1=BSD License
-javax.transaction--jta--1.1=COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
-jaxen--jaxen--1.1.1=http\://jaxen.codehaus.org/license.html
-jdom--jdom--1.0=The Apache Software License, Version 2.0
Modified: trunk/topia-persistence-hibernate/LICENSE.txt
===================================================================
--- trunk/topia-persistence-hibernate/LICENSE.txt 2012-12-30 21:41:01 UTC (rev 2703)
+++ trunk/topia-persistence-hibernate/LICENSE.txt 2012-12-30 21:43:38 UTC (rev 2704)
@@ -0,0 +1,166 @@
+ GNU LESSER GENERAL PUBLIC LICENSE
+ Version 3, 29 June 2007
+
+ Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>
+ Everyone is permitted to copy and distribute verbatim copies
+ of this license document, but changing it is not allowed.
+
+
+ This version of the GNU Lesser General Public License incorporates
+the terms and conditions of version 3 of the GNU General Public
+License, supplemented by the additional permissions listed below.
+
+ 0. Additional Definitions.
+
+ As used herein, "this License" refers to version 3 of the GNU Lesser
+General Public License, and the "GNU GPL" refers to version 3 of the GNU
+General Public License.
+
+ "The Library" refers to a covered work governed by this License,
+other than an Application or a Combined Work as defined below.
+
+ An "Application" is any work that makes use of an interface provided
+by the Library, but which is not otherwise based on the Library.
+Defining a subclass of a class defined by the Library is deemed a mode
+of using an interface provided by the Library.
+
+ A "Combined Work" is a work produced by combining or linking an
+Application with the Library. The particular version of the Library
+with which the Combined Work was made is also called the "Linked
+Version".
+
+ The "Minimal Corresponding Source" for a Combined Work means the
+Corresponding Source for the Combined Work, excluding any source code
+for portions of the Combined Work that, considered in isolation, are
+based on the Application, and not on the Linked Version.
+
+ The "Corresponding Application Code" for a Combined Work means the
+object code and/or source code for the Application, including any data
+and utility programs needed for reproducing the Combined Work from the
+Application, but excluding the System Libraries of the Combined Work.
+
+ 1. Exception to Section 3 of the GNU GPL.
+
+ You may convey a covered work under sections 3 and 4 of this License
+without being bound by section 3 of the GNU GPL.
+
+ 2. Conveying Modified Versions.
+
+ If you modify a copy of the Library, and, in your modifications, a
+facility refers to a function or data to be supplied by an Application
+that uses the facility (other than as an argument passed when the
+facility is invoked), then you may convey a copy of the modified
+version:
+
+ a) under this License, provided that you make a good faith effort to
+ ensure that, in the event an Application does not supply the
+ function or data, the facility still operates, and performs
+ whatever part of its purpose remains meaningful, or
+
+ b) under the GNU GPL, with none of the additional permissions of
+ this License applicable to that copy.
+
+ 3. Object Code Incorporating Material from Library Header Files.
+
+ The object code form of an Application may incorporate material from
+a header file that is part of the Library. You may convey such object
+code under terms of your choice, provided that, if the incorporated
+material is not limited to numerical parameters, data structure
+layouts and accessors, or small macros, inline functions and templates
+(ten or fewer lines in length), you do both of the following:
+
+ a) Give prominent notice with each copy of the object code that the
+ Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the object code with a copy of the GNU GPL and this license
+ document.
+
+ 4. Combined Works.
+
+ You may convey a Combined Work under terms of your choice that,
+taken together, effectively do not restrict modification of the
+portions of the Library contained in the Combined Work and reverse
+engineering for debugging such modifications, if you also do each of
+the following:
+
+ a) Give prominent notice with each copy of the Combined Work that
+ the Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the Combined Work with a copy of the GNU GPL and this license
+ document.
+
+ c) For a Combined Work that displays copyright notices during
+ execution, include the copyright notice for the Library among
+ these notices, as well as a reference directing the user to the
+ copies of the GNU GPL and this license document.
+
+ d) Do one of the following:
+
+ 0) Convey the Minimal Corresponding Source under the terms of this
+ License, and the Corresponding Application Code in a form
+ suitable for, and under terms that permit, the user to
+ recombine or relink the Application with a modified version of
+ the Linked Version to produce a modified Combined Work, in the
+ manner specified by section 6 of the GNU GPL for conveying
+ Corresponding Source.
+
+ 1) Use a suitable shared library mechanism for linking with the
+ Library. A suitable mechanism is one that (a) uses at run time
+ a copy of the Library already present on the user's computer
+ system, and (b) will operate properly with a modified version
+ of the Library that is interface-compatible with the Linked
+ Version.
+
+ e) Provide Installation Information, but only if you would otherwise
+ be required to provide such information under section 6 of the
+ GNU GPL, and only to the extent that such information is
+ necessary to install and execute a modified version of the
+ Combined Work produced by recombining or relinking the
+ Application with a modified version of the Linked Version. (If
+ you use option 4d0, the Installation Information must accompany
+ the Minimal Corresponding Source and Corresponding Application
+ Code. If you use option 4d1, you must provide the Installation
+ Information in the manner specified by section 6 of the GNU GPL
+ for conveying Corresponding Source.)
+
+ 5. Combined Libraries.
+
+ You may place library facilities that are a work based on the
+Library side by side in a single library together with other library
+facilities that are not Applications and are not covered by this
+License, and convey such a combined library under terms of your
+choice, if you do both of the following:
+
+ a) Accompany the combined library with a copy of the same work based
+ on the Library, uncombined with any other library facilities,
+ conveyed under the terms of this License.
+
+ b) Give prominent notice with the combined library that part of it
+ is a work based on the Library, and explaining where to find the
+ accompanying uncombined form of the same work.
+
+ 6. Revised Versions of the GNU Lesser General Public License.
+
+ The Free Software Foundation may publish revised and/or new versions
+of the GNU Lesser General Public License from time to time. Such new
+versions will be similar in spirit to the present version, but may
+differ in detail to address new problems or concerns.
+
+ Each version is given a distinguishing version number. If the
+Library as you received it specifies that a certain numbered version
+of the GNU Lesser General Public License "or any later version"
+applies to it, you have the option of following the terms and
+conditions either of that published version or of any later version
+published by the Free Software Foundation. If the Library as you
+received it does not specify a version number of the GNU Lesser
+General Public License, you may choose any version of the GNU Lesser
+General Public License ever published by the Free Software Foundation.
+
+ If the Library as you received it specifies that a proxy can decide
+whether future versions of the GNU Lesser General Public License shall
+apply, that proxy's public statement of acceptance of any version is
+permanent authorization for you to choose that version for the
+Library.
+
Added: trunk/topia-persistence-hibernate/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/topia-persistence-hibernate/src/license/THIRD-PARTY.properties (rev 0)
+++ trunk/topia-persistence-hibernate/src/license/THIRD-PARTY.properties 2012-12-30 21:43:38 UTC (rev 2704)
@@ -0,0 +1,25 @@
+# Generated by org.codehaus.mojo.license.AddThirdPartyMojo
+#-------------------------------------------------------------------------------
+# Already used licenses in project :
+# - Apache License 2.0
+# - BSD License
+# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
+# - Common Public License Version 1.0
+# - GNU Lesser General Public License, version 2.1
+# - Indiana University Extreme! Lab Software License, vesion 1.1.1
+# - Lesser General Public License (LGPL) v 3.0
+# - Lesser General Public License (LPGL)
+# - Lesser General Public License (LPGL) v 2.1
+# - MIT License
+# - MPL 1.1
+# - New BSD License
+# - The Apache Software License, Version 2.0
+# - The H2 License, Version 1.0
+# - license.txt
+#-------------------------------------------------------------------------------
+# Please fill the missing licenses for dependencies :
+#
+#
+#Sun Dec 30 22:42:18 CET 2012
+commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
+dom4j--dom4j--1.6.1=BSD License
Property changes on: trunk/topia-persistence-hibernate/src/license/THIRD-PARTY.properties
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision
Added: svn:eol-style
+ native
Modified: trunk/topia-persistence-tck/LICENSE.txt
===================================================================
--- trunk/topia-persistence-tck/LICENSE.txt 2012-12-30 21:41:01 UTC (rev 2703)
+++ trunk/topia-persistence-tck/LICENSE.txt 2012-12-30 21:43:38 UTC (rev 2704)
@@ -0,0 +1,166 @@
+ GNU LESSER GENERAL PUBLIC LICENSE
+ Version 3, 29 June 2007
+
+ Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>
+ Everyone is permitted to copy and distribute verbatim copies
+ of this license document, but changing it is not allowed.
+
+
+ This version of the GNU Lesser General Public License incorporates
+the terms and conditions of version 3 of the GNU General Public
+License, supplemented by the additional permissions listed below.
+
+ 0. Additional Definitions.
+
+ As used herein, "this License" refers to version 3 of the GNU Lesser
+General Public License, and the "GNU GPL" refers to version 3 of the GNU
+General Public License.
+
+ "The Library" refers to a covered work governed by this License,
+other than an Application or a Combined Work as defined below.
+
+ An "Application" is any work that makes use of an interface provided
+by the Library, but which is not otherwise based on the Library.
+Defining a subclass of a class defined by the Library is deemed a mode
+of using an interface provided by the Library.
+
+ A "Combined Work" is a work produced by combining or linking an
+Application with the Library. The particular version of the Library
+with which the Combined Work was made is also called the "Linked
+Version".
+
+ The "Minimal Corresponding Source" for a Combined Work means the
+Corresponding Source for the Combined Work, excluding any source code
+for portions of the Combined Work that, considered in isolation, are
+based on the Application, and not on the Linked Version.
+
+ The "Corresponding Application Code" for a Combined Work means the
+object code and/or source code for the Application, including any data
+and utility programs needed for reproducing the Combined Work from the
+Application, but excluding the System Libraries of the Combined Work.
+
+ 1. Exception to Section 3 of the GNU GPL.
+
+ You may convey a covered work under sections 3 and 4 of this License
+without being bound by section 3 of the GNU GPL.
+
+ 2. Conveying Modified Versions.
+
+ If you modify a copy of the Library, and, in your modifications, a
+facility refers to a function or data to be supplied by an Application
+that uses the facility (other than as an argument passed when the
+facility is invoked), then you may convey a copy of the modified
+version:
+
+ a) under this License, provided that you make a good faith effort to
+ ensure that, in the event an Application does not supply the
+ function or data, the facility still operates, and performs
+ whatever part of its purpose remains meaningful, or
+
+ b) under the GNU GPL, with none of the additional permissions of
+ this License applicable to that copy.
+
+ 3. Object Code Incorporating Material from Library Header Files.
+
+ The object code form of an Application may incorporate material from
+a header file that is part of the Library. You may convey such object
+code under terms of your choice, provided that, if the incorporated
+material is not limited to numerical parameters, data structure
+layouts and accessors, or small macros, inline functions and templates
+(ten or fewer lines in length), you do both of the following:
+
+ a) Give prominent notice with each copy of the object code that the
+ Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the object code with a copy of the GNU GPL and this license
+ document.
+
+ 4. Combined Works.
+
+ You may convey a Combined Work under terms of your choice that,
+taken together, effectively do not restrict modification of the
+portions of the Library contained in the Combined Work and reverse
+engineering for debugging such modifications, if you also do each of
+the following:
+
+ a) Give prominent notice with each copy of the Combined Work that
+ the Library is used in it and that the Library and its use are
+ covered by this License.
+
+ b) Accompany the Combined Work with a copy of the GNU GPL and this license
+ document.
+
+ c) For a Combined Work that displays copyright notices during
+ execution, include the copyright notice for the Library among
+ these notices, as well as a reference directing the user to the
+ copies of the GNU GPL and this license document.
+
+ d) Do one of the following:
+
+ 0) Convey the Minimal Corresponding Source under the terms of this
+ License, and the Corresponding Application Code in a form
+ suitable for, and under terms that permit, the user to
+ recombine or relink the Application with a modified version of
+ the Linked Version to produce a modified Combined Work, in the
+ manner specified by section 6 of the GNU GPL for conveying
+ Corresponding Source.
+
+ 1) Use a suitable shared library mechanism for linking with the
+ Library. A suitable mechanism is one that (a) uses at run time
+ a copy of the Library already present on the user's computer
+ system, and (b) will operate properly with a modified version
+ of the Library that is interface-compatible with the Linked
+ Version.
+
+ e) Provide Installation Information, but only if you would otherwise
+ be required to provide such information under section 6 of the
+ GNU GPL, and only to the extent that such information is
+ necessary to install and execute a modified version of the
+ Combined Work produced by recombining or relinking the
+ Application with a modified version of the Linked Version. (If
+ you use option 4d0, the Installation Information must accompany
+ the Minimal Corresponding Source and Corresponding Application
+ Code. If you use option 4d1, you must provide the Installation
+ Information in the manner specified by section 6 of the GNU GPL
+ for conveying Corresponding Source.)
+
+ 5. Combined Libraries.
+
+ You may place library facilities that are a work based on the
+Library side by side in a single library together with other library
+facilities that are not Applications and are not covered by this
+License, and convey such a combined library under terms of your
+choice, if you do both of the following:
+
+ a) Accompany the combined library with a copy of the same work based
+ on the Library, uncombined with any other library facilities,
+ conveyed under the terms of this License.
+
+ b) Give prominent notice with the combined library that part of it
+ is a work based on the Library, and explaining where to find the
+ accompanying uncombined form of the same work.
+
+ 6. Revised Versions of the GNU Lesser General Public License.
+
+ The Free Software Foundation may publish revised and/or new versions
+of the GNU Lesser General Public License from time to time. Such new
+versions will be similar in spirit to the present version, but may
+differ in detail to address new problems or concerns.
+
+ Each version is given a distinguishing version number. If the
+Library as you received it specifies that a certain numbered version
+of the GNU Lesser General Public License "or any later version"
+applies to it, you have the option of following the terms and
+conditions either of that published version or of any later version
+published by the Free Software Foundation. If the Library as you
+received it does not specify a version number of the GNU Lesser
+General Public License, you may choose any version of the GNU Lesser
+General Public License ever published by the Free Software Foundation.
+
+ If the Library as you received it specifies that a proxy can decide
+whether future versions of the GNU Lesser General Public License shall
+apply, that proxy's public statement of acceptance of any version is
+permanent authorization for you to choose that version for the
+Library.
+
Added: trunk/topia-persistence-tck/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/topia-persistence-tck/src/license/THIRD-PARTY.properties (rev 0)
+++ trunk/topia-persistence-tck/src/license/THIRD-PARTY.properties 2012-12-30 21:43:38 UTC (rev 2704)
@@ -0,0 +1,22 @@
+# Generated by org.codehaus.mojo.license.AddThirdPartyMojo
+#-------------------------------------------------------------------------------
+# Already used licenses in project :
+# - BSD License
+# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
+# - Common Public License Version 1.0
+# - Indiana University Extreme! Lab Software License, vesion 1.1.1
+# - Lesser General Public License (LGPL) v 3.0
+# - Lesser General Public License (LPGL)
+# - Lesser General Public License (LPGL) v 2.1
+# - MIT License
+# - New BSD License
+# - The Apache Software License, Version 2.0
+# - The H2 License, Version 1.0
+# - The MIT License
+#-------------------------------------------------------------------------------
+# Please fill the missing licenses for dependencies :
+#
+#
+#Sun Dec 30 22:42:14 CET 2012
+commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
+dom4j--dom4j--1.6.1=BSD License
Property changes on: trunk/topia-persistence-tck/src/license/THIRD-PARTY.properties
___________________________________________________________________
Added: svn:keywords
+ Author Date Id Revision
Added: svn:eol-style
+ native
Modified: trunk/topia-service-migration/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/topia-service-migration/src/license/THIRD-PARTY.properties 2012-12-30 21:41:01 UTC (rev 2703)
+++ trunk/topia-service-migration/src/license/THIRD-PARTY.properties 2012-12-30 21:43:38 UTC (rev 2704)
@@ -1,15 +1,18 @@
# Generated by org.codehaus.mojo.license.AddThirdPartyMojo
#-------------------------------------------------------------------------------
# Already used licenses in project :
+# - Apache License 2.0
# - BSD License
# - COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
# - Common Public License Version 1.0
+# - GNU Lesser General Public License, version 2.1
# - Indiana University Extreme! Lab Software License, vesion 1.1.1
# - Lesser General Public License (LGPL) v 3.0
# - Lesser General Public License (LPGL)
# - Lesser General Public License (LPGL) v 2.1
# - MIT License
# - MPL 1.1
+# - New BSD License
# - The Apache Software License, Version 2.0
# - The H2 License, Version 1.0
# - license.txt
@@ -17,8 +20,6 @@
# Please fill the missing licenses for dependencies :
#
#
-#Thu Aug 18 07:47:56 CEST 2011
-antlr--antlr--2.7.6=BSD License
+#Sun Dec 30 22:42:18 CET 2012
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
dom4j--dom4j--1.6.1=BSD License
-javax.transaction--jta--1.1=COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
Modified: trunk/topia-service-replication/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/topia-service-replication/src/license/THIRD-PARTY.properties 2012-12-30 21:41:01 UTC (rev 2703)
+++ trunk/topia-service-replication/src/license/THIRD-PARTY.properties 2012-12-30 21:43:38 UTC (rev 2704)
@@ -9,16 +9,12 @@
# - Lesser General Public License (LPGL)
# - Lesser General Public License (LPGL) v 2.1
# - MIT License
-# - MPL 1.1
+# - New BSD License
# - The Apache Software License, Version 2.0
-# - The H2 License, Version 1.0
-# - license.txt
#-------------------------------------------------------------------------------
# Please fill the missing licenses for dependencies :
#
#
-#Thu Aug 18 07:47:24 CEST 2011
-antlr--antlr--2.7.6=BSD License
+#Sun Dec 30 22:42:08 CET 2012
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
dom4j--dom4j--1.6.1=BSD License
-javax.transaction--jta--1.1=COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
Modified: trunk/topia-service-security/src/license/THIRD-PARTY.properties
===================================================================
--- trunk/topia-service-security/src/license/THIRD-PARTY.properties 2012-12-30 21:41:01 UTC (rev 2703)
+++ trunk/topia-service-security/src/license/THIRD-PARTY.properties 2012-12-30 21:43:38 UTC (rev 2704)
@@ -9,16 +9,13 @@
# - Lesser General Public License (LPGL)
# - Lesser General Public License (LPGL) v 2.1
# - MIT License
-# - MPL 1.1
+# - New BSD License
# - The Apache Software License, Version 2.0
# - The H2 License, Version 1.0
-# - license.txt
#-------------------------------------------------------------------------------
# Please fill the missing licenses for dependencies :
#
#
-#Thu Aug 18 07:48:01 CEST 2011
-antlr--antlr--2.7.6=BSD License
+#Sun Dec 30 22:42:20 CET 2012
commons-primitives--commons-primitives--1.0=The Apache Software License, Version 2.0
dom4j--dom4j--1.6.1=BSD License
-javax.transaction--jta--1.1=COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
1
0
Author: tchemit
Date: 2012-12-30 22:41:01 +0100 (Sun, 30 Dec 2012)
New Revision: 2703
Url: http://nuiton.org/projects/topia/repository/revisions/2703
Log:
optimize dependencies
Modified:
trunk/pom.xml
trunk/topia-persistence/pom.xml
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
+++ trunk/pom.xml 2012-12-30 21:41:01 UTC (rev 2703)
@@ -95,6 +95,7 @@
<groupId>org.nuiton.eugene</groupId>
<artifactId>eugene-java-templates</artifactId>
<version>${eugeneVersion}</version>
+ <scope>provided</scope>
</dependency>
<dependency>
Modified: trunk/topia-persistence/pom.xml
===================================================================
--- trunk/topia-persistence/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
+++ trunk/topia-persistence/pom.xml 2012-12-30 21:41:01 UTC (rev 2703)
@@ -60,10 +60,10 @@
<artifactId>eugene</artifactId>
</dependency>
- <!--dependency>
+ <dependency>
<groupId>org.nuiton.eugene</groupId>
<artifactId>eugene-java-templates</artifactId>
- </dependency-->
+ </dependency>
<dependency>
<groupId>commons-collections</groupId>
1
0
r2702 - in trunk: topia-persistence topia-persistence-hibernate topia-persistence-tck topia-service-migration topia-service-replication topia-service-security
by tchemit@users.nuiton.org 30 Dec '12
by tchemit@users.nuiton.org 30 Dec '12
30 Dec '12
Author: tchemit
Date: 2012-12-30 22:31:56 +0100 (Sun, 30 Dec 2012)
New Revision: 2702
Url: http://nuiton.org/projects/topia/repository/revisions/2702
Log:
optimize dependencies
Modified:
trunk/topia-persistence-hibernate/pom.xml
trunk/topia-persistence-tck/pom.xml
trunk/topia-persistence/pom.xml
trunk/topia-service-migration/pom.xml
trunk/topia-service-replication/pom.xml
trunk/topia-service-security/pom.xml
Modified: trunk/topia-persistence/pom.xml
===================================================================
--- trunk/topia-persistence/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
+++ trunk/topia-persistence/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
@@ -60,10 +60,10 @@
<artifactId>eugene</artifactId>
</dependency>
- <dependency>
+ <!--dependency>
<groupId>org.nuiton.eugene</groupId>
<artifactId>eugene-java-templates</artifactId>
- </dependency>
+ </dependency-->
<dependency>
<groupId>commons-collections</groupId>
Modified: trunk/topia-persistence-hibernate/pom.xml
===================================================================
--- trunk/topia-persistence-hibernate/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
+++ trunk/topia-persistence-hibernate/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
@@ -43,6 +43,31 @@
</dependency>
<dependency>
+ <groupId>org.nuiton.i18n</groupId>
+ <artifactId>nuiton-i18n</artifactId>
+ </dependency>
+
+ <dependency>
+ <groupId>org.apache.commons</groupId>
+ <artifactId>commons-lang3</artifactId>
+ </dependency>
+
+ <dependency>
+ <groupId>commons-logging</groupId>
+ <artifactId>commons-logging</artifactId>
+ </dependency>
+
+ <dependency>
+ <groupId>com.google.guava</groupId>
+ <artifactId>guava</artifactId>
+ </dependency>
+
+ <dependency>
+ <groupId>dom4j</groupId>
+ <artifactId>dom4j</artifactId>
+ </dependency>
+
+ <dependency>
<groupId>org.hibernate</groupId>
<artifactId>hibernate-core</artifactId>
</dependency>
@@ -54,6 +79,7 @@
<groupId>org.hibernate</groupId>
<artifactId>hibernate-ehcache</artifactId>
</dependency>
+
<dependency>
<groupId>org.hibernate.javax.persistence</groupId>
<artifactId>hibernate-jpa-2.0-api</artifactId>
Modified: trunk/topia-persistence-tck/pom.xml
===================================================================
--- trunk/topia-persistence-tck/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
+++ trunk/topia-persistence-tck/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
@@ -42,6 +42,7 @@
<groupId>org.nuiton</groupId>
<artifactId>nuiton-utils</artifactId>
</dependency>
+
<dependency>
<groupId>org.nuiton.i18n</groupId>
<artifactId>nuiton-i18n</artifactId>
@@ -51,11 +52,17 @@
<groupId>org.apache.commons</groupId>
<artifactId>commons-lang3</artifactId>
</dependency>
+
<dependency>
<groupId>commons-logging</groupId>
<artifactId>commons-logging</artifactId>
</dependency>
+ <dependency>
+ <groupId>com.google.guava</groupId>
+ <artifactId>guava</artifactId>
+ </dependency>
+
<!-- BD H2 for testing -->
<dependency>
<groupId>com.h2database</groupId>
Modified: trunk/topia-service-migration/pom.xml
===================================================================
--- trunk/topia-service-migration/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
+++ trunk/topia-service-migration/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
@@ -76,15 +76,27 @@
<version>${project.version}</version>
</dependency>
+ <dependency>
+ <groupId>org.hibernate.javax.persistence</groupId>
+ <artifactId>hibernate-jpa-2.0-api</artifactId>
+ </dependency>
+
+ <dependency>
+ <groupId>com.google.guava</groupId>
+ <artifactId>guava</artifactId>
+ </dependency>
+
<!-- Depencies for test-->
<dependency>
<groupId>com.h2database</groupId>
<artifactId>h2</artifactId>
</dependency>
+
<dependency>
<groupId>org.slf4j</groupId>
<artifactId>slf4j-log4j12</artifactId>
</dependency>
+
<dependency>
<groupId>junit</groupId>
<artifactId>junit</artifactId>
Modified: trunk/topia-service-replication/pom.xml
===================================================================
--- trunk/topia-service-replication/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
+++ trunk/topia-service-replication/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
@@ -50,8 +50,8 @@
</dependency>
<dependency>
- <groupId>org.nuiton.i18n</groupId>
- <artifactId>nuiton-i18n</artifactId>
+ <groupId>org.apache.geronimo.specs</groupId>
+ <artifactId>geronimo-jpa_2.0_spec</artifactId>
</dependency>
<dependency>
@@ -65,11 +65,6 @@
</dependency>
<dependency>
- <groupId>org.hibernate</groupId>
- <artifactId>hibernate-core</artifactId>
- </dependency>
-
- <dependency>
<groupId>org.slf4j</groupId>
<artifactId>slf4j-log4j12</artifactId>
</dependency>
Modified: trunk/topia-service-security/pom.xml
===================================================================
--- trunk/topia-service-security/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
+++ trunk/topia-service-security/pom.xml 2012-12-30 21:31:56 UTC (rev 2702)
@@ -45,30 +45,23 @@
<!-- Sibling dependencies -->
<dependency>
<groupId>${project.groupId}</groupId>
- <artifactId>topia-persistence-hibernate</artifactId>
+ <artifactId>topia-persistence</artifactId>
<version>${project.version}</version>
</dependency>
<dependency>
- <groupId>${project.groupId}</groupId>
- <artifactId>topia-persistence-tck</artifactId>
- <version>${project.version}</version>
- <!--<classifier>tests</classifier>-->
+ <groupId>org.apache.geronimo.specs</groupId>
+ <artifactId>geronimo-jpa_2.0_spec</artifactId>
</dependency>
<dependency>
- <groupId>org.nuiton</groupId>
- <artifactId>nuiton-utils</artifactId>
- </dependency>
-
- <dependency>
<groupId>org.apache.commons</groupId>
<artifactId>commons-lang3</artifactId>
</dependency>
<dependency>
- <groupId>commons-collections</groupId>
- <artifactId>commons-collections</artifactId>
+ <groupId>com.google.guava</groupId>
+ <artifactId>guava</artifactId>
</dependency>
<dependency>
@@ -76,11 +69,6 @@
<artifactId>commons-logging</artifactId>
</dependency>
- <dependency>
- <groupId>org.hibernate</groupId>
- <artifactId>hibernate-core</artifactId>
- </dependency>
-
<!-- Depencies for test-->
<dependency>
<groupId>com.h2database</groupId>
1
0
r2701 - in trunk: . topia-persistence/src/main/java/org/nuiton/topia/persistence topia-service-security
by tchemit@users.nuiton.org 30 Dec '12
by tchemit@users.nuiton.org 30 Dec '12
30 Dec '12
Author: tchemit
Date: 2012-12-30 21:18:25 +0100 (Sun, 30 Dec 2012)
New Revision: 2701
Url: http://nuiton.org/projects/topia/repository/revisions/2701
Log:
updates some libs
Modified:
trunk/pom.xml
trunk/topia-persistence/src/main/java/org/nuiton/topia/persistence/TopiaFilterPagerUtil.java
trunk/topia-service-security/pom.xml
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-12-30 20:03:54 UTC (rev 2700)
+++ trunk/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
@@ -69,14 +69,14 @@
<!-- libs version -->
<eugeneVersion>2.6</eugeneVersion>
- <nuitonUtilsVersion>2.4.8</nuitonUtilsVersion>
+ <nuitonUtilsVersion>2.6.5</nuitonUtilsVersion>
<processorPluginVersion>1.2.2</processorPluginVersion>
- <nuitonI18nVersion>2.4.1</nuitonI18nVersion>
+ <nuitonI18nVersion>2.5</nuitonI18nVersion>
<xmlrpcVersion>3.1.2</xmlrpcVersion>
- <hibernateVersion>4.1.3.Final</hibernateVersion>
- <sl4jVersion>1.6.4</sl4jVersion>
- <h2Version>1.3.167</h2Version>
- <mockitoVersion>1.9.0</mockitoVersion>
+ <hibernateVersion>4.1.9.Final</hibernateVersion>
+ <sl4jVersion>1.7.2</sl4jVersion>
+ <h2Version>1.3.170</h2Version>
+ <mockitoVersion>1.9.5</mockitoVersion>
<geronimoJpaSpecVersion>1.1</geronimoJpaSpecVersion>
</properties>
@@ -212,21 +212,20 @@
<developer>
<name>Benjamin Poussin</name>
<id>bpoussin</id>
- <email>poussin(a)codelutin.com</email>
+ <email>poussin at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Développeur</role>
- <role>Debian packager</role>
</roles>
</developer>
<developer>
<name>Arnaud Thimel</name>
<id>athimel</id>
- <email>thimel(a)codelutin.com</email>
+ <email>thimel at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Développeur</role>
</roles>
@@ -235,9 +234,9 @@
<developer>
<name>Julien Ruchaud</name>
<id>jruchaud</id>
- <email>ruchaud(a)codelutin.com</email>
+ <email>ruchaud at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Développeur</role>
</roles>
@@ -246,9 +245,9 @@
<developer>
<name>Eric Chatellier</name>
<id>echatellier</id>
- <email>chatellier(a)codelutin.com</email>
+ <email>chatellier at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Développeur</role>
</roles>
@@ -257,9 +256,9 @@
<developer>
<name>Tony Chemit</name>
<id>tchemit</id>
- <email>chemit(a)codelutin.com</email>
+ <email>chemit at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Développeur</role>
</roles>
@@ -268,31 +267,20 @@
<developer>
<name>Sylvain Letellier</name>
<id>sletellier</id>
- <email>letellier(a)codelutin.com</email>
+ <email>letellier at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Développeur</role>
</roles>
</developer>
<developer>
- <name>Florian Desbois</name>
- <id>fdesbois</id>
- <email>desbois(a)codelutin.com</email>
- <organization>CodeLutin</organization>
- <timezone>+2</timezone>
- <roles>
- <role>Développeur</role>
- </roles>
- </developer>
-
- <developer>
<name>Brendan Le Ny</name>
<id>bleny</id>
- <email>bleny(a)codelutin.com</email>
+ <email>bleny at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Développeur</role>
</roles>
@@ -301,9 +289,9 @@
<developer>
<name>Jean Couteau</name>
<id>jcouteau</id>
- <email>couteau(a)codelutin.com</email>
+ <email>couteau at codelutin dot com</email>
<organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
<roles>
<role>Documentation writer</role>
</roles>
@@ -313,40 +301,31 @@
<contributors>
<contributor>
<name>Nicolas Dupont</name>
- <email>ndupont(a)codelutin.com</email>
- <organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
</contributor>
<contributor>
<name>Eduardo Ore</name>
- <email>eore(a)codelutin.com</email>
- <organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
</contributor>
<contributor>
<name>Gabriel Landais</name>
- <email>glandais(a)codelutin.com</email>
- <organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
</contributor>
<contributor>
<name>Stéphane Chorlet</name>
- <email>schorlet(a)codelutin.com</email>
- <organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
</contributor>
<contributor>
<name>Jonathan pepin</name>
- <email>jpepin(a)codelutin.com</email>
- <organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
</contributor>
<contributor>
<name>Nolwenn Ranou</name>
- <email>nrannou(a)codelutin.com</email>
- <organization>CodeLutin</organization>
- <timezone>+2</timezone>
+ <timezone>Europe/Paris</timezone>
</contributor>
+ <contributor>
+ <name>Florian Desbois</name>
+ </contributor>
</contributors>
<!-- ************************************************************* -->
@@ -458,6 +437,7 @@
<report>license</report>
<report>scm</report>
<report>dependencies</report>
+ <report>dependency-info</report>
<report>dependency-convergence</report>
<report>plugin-management</report>
<report>plugins</report>
@@ -508,7 +488,9 @@
<!-- Source control management. -->
<scm>
<connection>scm:svn:http://svn.nuiton.org/svn/topia/trunk</connection>
- <developerConnection>scm:svn:http://svn.nuiton.org/svn/topia/trunk</developerConnection>
+ <developerConnection>
+ scm:svn:http://svn.nuiton.org/svn/topia/trunk
+ </developerConnection>
<url>http://www.nuiton.org/projects/topia/repository/show/trunk</url>
</scm>
Modified: trunk/topia-persistence/src/main/java/org/nuiton/topia/persistence/TopiaFilterPagerUtil.java
===================================================================
--- trunk/topia-service-security/pom.xml 2012-12-30 20:03:54 UTC (rev 2700)
+++ trunk/topia-service-security/pom.xml 2012-12-30 20:18:25 UTC (rev 2701)
@@ -155,7 +155,7 @@
<dependency>
<groupId>org.apache.geronimo.specs</groupId>
<artifactId>geronimo-jpa_2.0_spec</artifactId>
- <version>1.1</version>
+ <version>${geronimoJpaSpecVersion}</version>
<scope>compile</scope>
</dependency>
</dependencies>
1
0
Author: tchemit
Date: 2012-12-30 21:03:54 +0100 (Sun, 30 Dec 2012)
New Revision: 2700
Url: http://nuiton.org/projects/topia/repository/revisions/2700
Log:
do not use any longer juni.framework deprecated package
Modified:
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/EnumTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/events/VetoableEventTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/IsPersistentTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/TopiaContextFindTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationWithRoleNamedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationWithRoleNamedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/EntityWithBasicUniqueFieldsTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyUniqueTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyWithRoleNamedUniqueTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyUniqueTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyWithRoleNamedUniqueTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test12/EntityWithBasicNotNullFieldsTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test13/EntityWithNaturalIdTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationWithRoleNamedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationWithRoleNamedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationWithRoleNamedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationWithRoleNamedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test4/ElementCollectionTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/BiDirectionalOneToManyCompositionTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/OneToManyCompositionTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyIndexedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyWithRoleNamedIndexedTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderByTest.java
trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderedTest.java
trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/EnumTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/EnumTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/EnumTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -24,7 +24,7 @@
*/
package org.nuiton.topia.tck.it;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Rule;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/events/VetoableEventTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/events/VetoableEventTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/events/VetoableEventTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.it.events;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.Rule;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/IsPersistentTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/IsPersistentTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/IsPersistentTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.it.persistence;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Rule;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/TopiaContextFindTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/TopiaContextFindTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/it/persistence/TopiaContextFindTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.it.persistence;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test1;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationWithRoleNamedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/BiDirectionalOneToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test1;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test1;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationWithRoleNamedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test1/SimpleOneToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test1;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/EntityWithBasicUniqueFieldsTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/EntityWithBasicUniqueFieldsTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/EntityWithBasicUniqueFieldsTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test11;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyUniqueTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyUniqueTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyUniqueTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test11;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyWithRoleNamedUniqueTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyWithRoleNamedUniqueTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleManyToManyWithRoleNamedUniqueTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test11;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyUniqueTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyUniqueTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyUniqueTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test11;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyWithRoleNamedUniqueTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyWithRoleNamedUniqueTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test11/SimpleOneToManyWithRoleNamedUniqueTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test11;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test12/EntityWithBasicNotNullFieldsTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test12/EntityWithBasicNotNullFieldsTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test12/EntityWithBasicNotNullFieldsTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test12;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test13/EntityWithNaturalIdTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test13/EntityWithNaturalIdTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test13/EntityWithNaturalIdTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test13;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test2;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationWithRoleNamedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationWithRoleNamedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/BiDirectionalManyToOneRelationWithRoleNamedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test2;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test2;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationWithRoleNamedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationWithRoleNamedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test2/SimpleManyToOneRelationWithRoleNamedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test2;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test3;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationWithRoleNamedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/BiDirectionalManyToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test3;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test3;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationWithRoleNamedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test3/SimpleManyToManyRelationWithRoleNamedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test3;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test4/ElementCollectionTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test4/ElementCollectionTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test4/ElementCollectionTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test4;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/BiDirectionalOneToManyCompositionTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/BiDirectionalOneToManyCompositionTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/BiDirectionalOneToManyCompositionTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test5;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/OneToManyCompositionTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/OneToManyCompositionTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test5/OneToManyCompositionTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -23,7 +23,7 @@
*/
package org.nuiton.topia.tck.mapping.test5;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyIndexedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyIndexedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyIndexedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -24,7 +24,7 @@
package org.nuiton.topia.tck.mapping.test6;
import com.google.common.collect.Lists;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyWithRoleNamedIndexedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyWithRoleNamedIndexedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test6/SimpleOneToManyWithRoleNamedIndexedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -24,7 +24,7 @@
package org.nuiton.topia.tck.mapping.test6;
import com.google.common.collect.Lists;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderByTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderByTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderByTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -24,7 +24,7 @@
package org.nuiton.topia.tck.mapping.test7;
import com.google.common.collect.Lists;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderedTest.java
===================================================================
--- trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderedTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-persistence-tck/src/test/java/org/nuiton/topia/tck/mapping/test7/SimpleOneToManyOrderedTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -24,7 +24,7 @@
package org.nuiton.topia.tck.mapping.test7;
import com.google.common.collect.Lists;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.nuiton.topia.TopiaContext;
Modified: trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java
===================================================================
--- trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java 2012-12-30 20:03:11 UTC (rev 2699)
+++ trunk/topia-service-migration/src/test/java/org/nuiton/topia/migration/TckItMigrationTest.java 2012-12-30 20:03:54 UTC (rev 2700)
@@ -2,7 +2,7 @@
import com.google.common.io.Files;
import com.google.common.io.InputSupplier;
-import junit.framework.Assert;
+import org.junit.Assert;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.Before;
1
0
Author: tchemit
Date: 2012-12-30 21:03:11 +0100 (Sun, 30 Dec 2012)
New Revision: 2699
Url: http://nuiton.org/projects/topia/repository/revisions/2699
Log:
fixes #2269: Updates to eugene 2.6
Modified:
trunk/pom.xml
trunk/topia-persistence/pom.xml
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-12-29 11:29:49 UTC (rev 2698)
+++ trunk/pom.xml 2012-12-30 20:03:11 UTC (rev 2699)
@@ -68,7 +68,7 @@
<projectId>topia</projectId>
<!-- libs version -->
- <eugeneVersion>2.6-SNAPSHOT</eugeneVersion>
+ <eugeneVersion>2.6</eugeneVersion>
<nuitonUtilsVersion>2.4.8</nuitonUtilsVersion>
<processorPluginVersion>1.2.2</processorPluginVersion>
<nuitonI18nVersion>2.4.1</nuitonI18nVersion>
@@ -92,6 +92,12 @@
</dependency>
<dependency>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene-java-templates</artifactId>
+ <version>${eugeneVersion}</version>
+ </dependency>
+
+ <dependency>
<groupId>org.nuiton</groupId>
<artifactId>nuiton-utils</artifactId>
<version>${nuitonUtilsVersion}</version>
Modified: trunk/topia-persistence/pom.xml
===================================================================
--- trunk/topia-persistence/pom.xml 2012-12-29 11:29:49 UTC (rev 2698)
+++ trunk/topia-persistence/pom.xml 2012-12-30 20:03:11 UTC (rev 2699)
@@ -61,6 +61,11 @@
</dependency>
<dependency>
+ <groupId>org.nuiton.eugene</groupId>
+ <artifactId>eugene-java-templates</artifactId>
+ </dependency>
+
+ <dependency>
<groupId>commons-collections</groupId>
<artifactId>commons-collections</artifactId>
</dependency>
1
0
Author: tchemit
Date: 2012-12-29 12:29:49 +0100 (Sat, 29 Dec 2012)
New Revision: 2698
Url: http://nuiton.org/projects/topia/repository/revisions/2698
Log:
Update mavenpom4redmineAndCentral to 3.4.7.
Modified:
branches/topia-2.6.x/pom.xml
Modified: branches/topia-2.6.x/pom.xml
===================================================================
--- branches/topia-2.6.x/pom.xml 2012-12-29 11:29:45 UTC (rev 2697)
+++ branches/topia-2.6.x/pom.xml 2012-12-29 11:29:49 UTC (rev 2698)
@@ -33,7 +33,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>mavenpom4redmineAndCentral</artifactId>
- <version>3.4.4</version>
+ <version>3.4.7</version>
</parent>
<artifactId>topia</artifactId>
1
0
Author: tchemit
Date: 2012-12-29 12:29:45 +0100 (Sat, 29 Dec 2012)
New Revision: 2697
Url: http://nuiton.org/projects/topia/repository/revisions/2697
Log:
Update mavenpom4redmineAndCentral to 3.4.7.
Modified:
trunk/pom.xml
Modified: trunk/pom.xml
===================================================================
--- trunk/pom.xml 2012-11-25 11:09:42 UTC (rev 2696)
+++ trunk/pom.xml 2012-12-29 11:29:45 UTC (rev 2697)
@@ -32,7 +32,7 @@
<parent>
<groupId>org.nuiton</groupId>
<artifactId>mavenpom4redmineAndCentral</artifactId>
- <version>3.4.4</version>
+ <version>3.4.7</version>
</parent>
<artifactId>topia</artifactId>
1
0
--- trunk/topia-persistence/src/main/java/org/nuiton/topia/persistence/TopiaFilterPagerUtil.java 2012-12-30 20:03:54 UTC (rev 2700)
+++ trunk/topia-persistence/src/main/java/org/nuiton/topia/persistence/TopiaFilterPagerUtil.java 2012-12-30 20:18:25 UTC (rev 2701)
@@ -27,7 +27,8 @@
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.nuiton.topia.framework.TopiaQuery;
-import org.nuiton.util.PagerUtil;
+import org.nuiton.util.PagerBean;
+import org.nuiton.util.PagerBeanUtil;
import java.io.Serializable;
import java.util.ArrayList;
@@ -37,13 +38,13 @@
import java.util.Map;
/**
* Extension of the simple {@link PagerUtil} from nuiton-utils to offer
* order and filter api.
*
* @author tchemit <chemit(a)codelutin.com>
* @since 2.6.9
*/
-public class TopiaFilterPagerUtil extends PagerUtil {
+public class TopiaFilterPagerUtil extends PagerBeanUtil {
protected TopiaFilterPagerUtil() {
}
@@ -51,9 +52,9 @@
@Deprecated
public static TopiaQuery addPagerToQuery(TopiaQuery query,
FilterPagerBean pager) {
- PagerUtil.computeRecordIndexesAndPagesNumber(pager);
- query.setLimit(pager.getRecordStartIndex(),
- pager.getRecordEndIndex() - 1);
+ computeRecordIndexesAndPagesNumber(pager);
+ query.setLimit((int) pager.getRecordStartIndex(),
+ (int) pager.getRecordEndIndex() - 1);
if (StringUtils.isNotEmpty(pager.getSortColumn())) {
if (pager.isSortAscendant()) {
@@ -68,7 +69,7 @@
public static <E> List<E> getPageFromList(List<E> elements,
FilterPagerBean pager) {
- PagerUtil.computeRecordIndexesAndPagesNumber(pager);
+ computeRecordIndexesAndPagesNumber(pager);
List<E> subList = getPage(elements, pager.getPageIndex(), pager.getPageSize());
List<E> result = new ArrayList<E>(subList);
Modified: trunk/topia-service-security/pom.xml
@@ -37,13 +38,13 @@
import java.util.Map;
/**
- * Extension of the simple {@link PagerUtil} from nuiton-utils to offer
+ * Extension of the simple {@link PagerBeanUtil} from nuiton-utils to offer
* order and filter api.
*
===================================================================